<?php
	
	declare(strict_types=1);
	
	/**
	 * User: Daschmi (daschmi@daschmi.de)
	 * Date: 20.02.2020
	 * Time: 15:47
	 */ 
    
    namespace dywc;
    
    abstract class Settings {
    	
    	public static function form() : void {
    		
    		if (isset($_REQUEST['submit'])) {
    			
    			$arJSONSanitized = [];
			
				$arJSON = @json_decode($_REQUEST['json'], true);
    			if (!is_array($arJSON)) $arJSON = @json_decode(stripslashes($_REQUEST['json']), true);
    			
    			if (!is_array($arJSON)) {
				
					$_SESSION['ds_error'] = [__('Keine Konfigurationsdaten übergeben.', 'dywc')];
    				
				} else {
					
    				$arJSONSanitized['cookie_version'] = intval($arJSON['cookie_version']);
					$arJSONSanitized['cookie_name'] = \sanitize_text_field($arJSON['cookie_name']);
					$arJSONSanitized['cookie_expire'] = intval($arJSON['cookie_name']);
					$arJSONSanitized['cookie_path'] = \sanitize_text_field($arJSON['cookie_path']);
					$arJSONSanitized['mode'] = intval($arJSON['mode']);
					$arJSONSanitized['bglayer'] = ($arJSON['bglayer'] === true?true:false);
					$arJSONSanitized['position'] = \sanitize_text_field($arJSON['position']);
					$arJSONSanitized['id_bglayer'] = \sanitize_text_field($arJSON['id_bglayer']);
					$arJSONSanitized['id_cookielayer'] = \sanitize_text_field($arJSON['id_cookielayer']);
					$arJSONSanitized['id_cookieinfo'] = \sanitize_text_field($arJSON['id_cookieinfo']);
					$arJSONSanitized['url_legalnotice'] = \esc_url_raw($arJSON['url_legalnotice']);
					$arJSONSanitized['url_imprint'] = \esc_url_raw($arJSON['url_imprint']);
					$arJSONSanitized['text_title'] = \sanitize_text_field($arJSON['text_title']);
					$arJSONSanitized['text_dialog'] = \sanitize_text_field($arJSON['text_dialog']);
					$arJSONSanitized['cookie_groups'] = [];
					
					if (is_array($arJSON['cookie_groups']??null)) {
						
						foreach ($arJSON['cookie_groups'] as $cg) {
							
							$arCGSanitized = [];
							$arCGSanitized['label'] = \sanitize_text_field($cg['label']);
							$arCGSanitized['fixed'] = ($cg['fixed'] === true?true:false);
							$arCGSanitized['info'] = \sanitize_text_field($cg['info']);
							$arCGSanitized['accept'] = $cg['accept'];
							$arCGSanitized['reject'] = $cg['reject'];
							$arCGSanitized['cookies'] = [];
							
							if (is_array($cg['cookies']??null)) {
								
								foreach ($cg['cookies'] as $c) {
									
									$cSanitized = [];
									$cSanitized['label'] = \sanitize_text_field($c['label']);
									$cSanitized['publisher'] = \sanitize_text_field($c['publisher']);
									$cSanitized['aim'] = \sanitize_text_field($c['aim']);
									$cSanitized['name'] = \sanitize_text_field($c['name']);
									$cSanitized['duration'] = \sanitize_text_field($c['duration']);									
									
									$arCGSanitized['cookies'][] = $cSanitized;
									
								}
								
							} 
							
							$arJSONSanitized['cookie_groups'][] = $arCGSanitized;
							
						}
						
					}
				
					\update_option('dywc_json', $arJSONSanitized);
					
					$_SESSION['ds_msg'] = [__('Konfiguration erfolgreich gespeichert.', 'dywc')];
					
				}
    			
    			header('Location: '.\site_url().'/wp-admin/options-general.php?page=dywc_settings');
    			exit;
    			
			} else if (isset($_REQUEST['submit-reset'])) {
			
				\update_option('dywc_json', false);
			
				$_SESSION['ds_msg'] = [__('Konfiguration wurde zurückgesetzt.', 'dywc')];
				
				header('Location: '.\site_url().'/wp-admin/options-general.php?page=dywc_settings');
				exit;				
    			
			} else {
			
    			$view = [
    				'json' => \get_option('dywc_json')
				];
    			
    			if (!is_array($view['json'])) $view['json'] = [	
					'cookie_version' => 1,
					'cookie_name' => 'dywc',
					'cookie_expire' => 31536e3,
					'cookie_path' => '/', 
					'mode' => 1,  
					'bglayer' => true,
					'position' => 'mm',
					'id_bglayer' => 'dywc_bglayer',
					'id_cookielayer' => 'dywc',
					'id_cookieinfo' => 'dywc_info',
					'url_legalnotice' => '/datenschutzerklaerung.html',
					'url_imprint' => '/impressum.html', 
					'text_title' => 'Datenschutzeinstellungen',
					'text_dialog' => 'Wir nutzen Cookies auf unserer Website. Einige von ihnen sind essenziell, während andere uns helfen, diese Website und Ihre Erfahrung zu verbessern.',
					'cookie_groups' => [
						[
							'label' => 'Notwendig',
							'fixed' => true,
							'info' => 'Zum Betrieb der Seite notwendige Cookies:',
							'accept' => "",
							'reject' => "",
							'cookies' => [
								[
									'label' => 'PHP Session Cookie',
									'publisher' => 'Eigentümer dieser Website',
									'aim' => 'Absicherung Kontaktformular / SPAM Schutz',
									'name' => 'PHPSESSID',
									'duration' => 'Session'
								], [
									'label' => 'Cookiespeicherung Entscheidungscookie',
									'publisher' => 'Eigentümer dieser Website',
									'aim' => 'Speichert die Einstellungen der Besucher bezüglich der Speicherung von Cookies.',
									'name' => 'dywc',
									'duration' => '1 Jahr'
								]
							]
						], [
							'label' => 'Statistiken',
							'fixed' => false,
							'info' => 'Cookies die zur Auswertung des Benutzerverhaltens notwendig sind:',							
							'accept' => "
									
(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
   (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
   m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
})(window,document,'script','https://www.google-analytics.com/analytics.js','ga');

ga('create', 'UA-{TRACKINGID}', 'auto');
ga('send', 'pageview');
									
                           ",
							'reject' => "

var disableStr = 'ga-disable-UA-{TRACKINGID}';

window[disableStr] = true; document.cookie = disableStr + '=true; expires=Thu, 31 Dec 2099 23:59:59 UTC; path=/';

dywc.cookie.removeItem('_ga', '/');
dywc.cookie.removeItem('_gid', '/');
dywc.cookie.removeItem('_gat', '/');
dywc.cookie.removeItem('_gat_gtag_UA-{TRACKINGID}', '/');

                           ", 
							'cookies' => [
								[
									'label' => 'Google Analytics',
									'publisher' => 'Google LLC',
									'aim' => 'Cookie von Google für Website-Analysen. Erzeugt statistische Daten darüber, wie der Besucher die Website nutzt.',
									'name' => '_ga,_gid',
									'duration' => '2 Jahre',
								]
							],
						]
					]
				];
			
				\update_option('dywc_json', $view['json']);
    			    			
				echo Renderer::render('settings/form.phtml', $view);	
    			
			}
    		
		}
    	
	}